/*
  Project:  4x3 rigid keypad / security code
  Function: This sketch takes input from a keypad for secret code.  If the code is
           entered correctly it turns on a green LED to simulate access granted and
           prints access granted in Serial Monitor. Otherwise the red LED is lit and
           access denied is printed in Serial Monitor.
*/
//******************************************************************************************
#include <Keypad.h>//include library code
//******************************************************************************************
const int greenledPin = 10;   //green LED attached to digital pin 10
const int redledPin = 11;     //red LED attached to digital pin 11
#define Password_Lenght 9     //give enough room for 8 chars + NULL char
char Data[Password_Lenght];   //8 is the number of chars it can hold + the null char = 9
char Master[Password_Lenght] = "12345678";//default password is 12345678
byte data_count = 0;          //variable to store the number counting
const byte rows = 4; //four rows
const byte cols = 3; //three columns
char keys[rows][cols] = {//define the symbols on the buttons of the keypads
  {'1','2','3'},
  {'4','5','6'},
  {'7','8','9'},
  {'#','0','*'}
};
byte rowPins[rows] = {7, 2, 3, 5}; //connect to the row pinouts of the keypad
byte colPins[cols] = {6, 8, 4};    //connect to the column pinouts of the keypad
Keypad customKeypad = Keypad( makeKeymap(keys), rowPins, colPins, rows, cols );
//**********************************************************************************************
void setup()
{
  pinMode(greenledPin, OUTPUT);         //sets greenledPin as OUTPUT
  pinMode(redledPin, OUTPUT);           //sets redledPin as OUTPUT
  Serial.begin(9600);                   //initialise the serial communication at 9600 bps
  Serial.println("********************");
  Serial.println("*****Electronic*****");
  Serial.println("*****Keypad Lock****");
  Serial.println("********************");
  delay(2000);                          //sets delay for 2 seconds
  Serial.println("*****Enter code*****");
}

void loop()
{
  char customKey = customKeypad.getKey();//reads the key pressed
  if (customKey) // makes sure that the key is actually pressed
  {
    Data[data_count] = customKey; // store char into data array
    Serial.print(customKey); // print char at said cursor
    data_count++; // increment data array by 1 to store new char, also keep track of the number of chars entered
  }

  if (data_count == Password_Lenght - 1) // if the array index is equal to the number of expected chars, compare data to master
  {
    if (!strcmp(Data, Master)) {
      digitalWrite(greenledPin, HIGH);//green LED is on
      Serial.println("");
      Serial.println("********************");
      Serial.println("** ACCESS GRANTED **");
      Serial.println("**   WELCOME!!    **");
      Serial.println("********************");
      delay(2000);//sets delay for 2 seconds
      digitalWrite(greenledPin, LOW);//green LED is off
      resetAll ();//reset all function
    }

    else {
      digitalWrite(redledPin, HIGH);//red LED is on
      Serial.println("");
      Serial.println("********************");
      Serial.println("** ACCESS DENIED! **");
      Serial.println("**  INVALID CODE  **");
      Serial.println("********************");
      delay(2000);//sets delay for 2 seconds
      digitalWrite(redledPin, LOW);//red LED is off
      resetAll ();//reset all function
    }
  }
}
void resetAll ()
{
  Serial.println("********************");
  Serial.println("*****Electronic*****");
  Serial.println("*****Keypad Lock****");
  Serial.println("********************");
  delay(2000);//sets delay for 2 seconds
  Serial.println("*****Enter code*****");
  while (data_count != 0)
  { 
    Data[data_count--] = 0; //clear array for new data
  }
  return;
}
